@@ -22,10 +22,16 @@ from .exceptions import plot_exceptions
 from .exceptions import radar_exceptions
 from .exceptions.warning_formatting import standard_warning_format
 from .exceptions.warning_formatting import only_message_warning_format
+from .exceptions.warning_formatting import citing_warning
 
 # importing utils
+from .utils.coordinates import Coords
+from .utils.constants import Re
+from .utils.constants import EARTH_EQUATORIAL_RADIUS
+from .utils.constants import C
 from .utils.conversions import dmap2dict
 from .utils.conversions import gate2slant
+from .utils.conversions import gate2GroundScatter
 from .utils.plotting import check_data_type
 from .utils.plotting import time2datetime
 from .utils.superdarn_radars import SuperDARNRadars
@@ -38,8 +44,10 @@ from .utils.radar_pos import radar_fov
 
 # import plotting
 from .plotting.color_maps import PyDARNColormaps
+from .plotting.axis import Projections
 from .plotting.rtp import RTP
 from .plotting.fan import Fan
+from .plotting.grid import Grid
 from .plotting.acf import ACF
 from .plotting.power import Power
-from .plotting.grid import Grid
+
