@@ -2,6 +2,20 @@
 # Author: Marina Schmidt
 # This code is improvement based on rti.py in the DaVitpy library
 # https://github.com/vtsuperdarn/davitpy/blob/master/davitpy
+#
+# Modifications:
+# 2021-05-12 Francis Tholley added gate2grounscatter to range-time plots
+#
+# Disclaimer:
+# pyDARN is under the LGPL v3 license found in the root directory LICENSE.md
+# Everyone is permitted to copy and distribute verbatim copies of this license
+# document, but changing it is not allowed.
+#
+# This version of the GNU Lesser General Public License incorporates the terms
+# and conditions of version 3 of the GNU General Public License,
+# supplemented by the additional permissions listed below.
+#
+
 
 """
 Range-Time Parameter (aka Intensity) plots
@@ -14,10 +28,11 @@ from datetime import datetime, timedelta
 from matplotlib import dates, colors, cm, ticker
 from typing import List
 
-from pydarn import (gate2slant, check_data_type, time2datetime,
-                    rtp_exceptions, plot_exceptions, SuperDARNCpids,
-                    SuperDARNRadars, standard_warning_format,
-                    PyDARNColormaps)
+from pydarn import (gate2GroundScatter, gate2slant, check_data_type,
+                    time2datetime, rtp_exceptions, plot_exceptions,
+                    SuperDARNCpids, SuperDARNRadars,
+                    standard_warning_format, PyDARNColormaps,
+                    Coords, citing_warning)
 
 warnings.formatwarning = standard_warning_format
 
@@ -56,9 +71,10 @@ class RTP():
                         start_time: datetime = None, end_time: datetime = None,
                         colorbar: plt.colorbar = None, ymin: int = None,
                         ymax: int = None, yspacing: int = 200,
-                        slant: bool = True, colorbar_label: str = '',
-                        norm=colors.Normalize,
-                        cmap: str = None,
+                        coords: object = Coords.SLANT_RANGE,
+                        reflection_height: float = 250.0,
+                        colorbar_label: str = '',
+                        norm=colors.Normalize, cmap: str = None,
                         filter_settings: dict = {},
                         date_fmt: str = '%y/%m/%d\n %H:%M', **kwargs):
         """
@@ -109,10 +125,13 @@ class RTP():
         yspacing: int
             sets the spacing between ticks
             Default: 200
-        slant: boolean
-            set the y-axis to slant range (km)
-            if false will show gate numbers.
-            Default: True
+        coords: Coords
+            set the y-axis to a desired coordinate system
+            Default: Coords.SLANT_RANGE
+        reflection_height: float
+            set the ionosphere virtual reflection height
+            this only applies to Coords.GROUND_SCATTER_MAPPED_RANGE
+            Default: 250 (km)
         norm: matplotlib.colors.Normalization object
             This object use dependency injection to use any normalization
             method with the zmin and zmax.
@@ -336,8 +355,19 @@ class RTP():
                                      start_time=start_time,
                                      end_time=end_time,
                                      opt_beam_num=cls.dmap_data[0]['bmnum'])
-        if slant:
-            y = gate2slant(cls.dmap_data[0], y_max)
+        if coords is Coords.SLANT_RANGE:
+            # Get rxrise from hardware files (consistent with RST)
+            rxrise = SuperDARNRadars.radars[cls.dmap_data[0]['stid']]\
+                                    .hardware_info.rx_rise_time
+            y = gate2slant(cls.dmap_data[0], y_max, rxrise=rxrise)
+        elif coords is Coords.GROUND_SCATTER_MAPPED_RANGE:
+            rxrise = SuperDARNRadars.radars[cls.dmap_data[0]['stid']]\
+                                    .hardware_info.rx_rise_time
+            y = gate2slant(cls.dmap_data[0], y_max, rxrise=rxrise)
+            y = gate2GroundScatter(y, reflection_height)
+            y0inx = np.min(np.where(np.isfinite(y))[0])
+            y = y[y0inx:]
+            z = z[:,y0inx:]
         time_axis, y_axis = np.meshgrid(x, y)
         z_data = np.ma.masked_where(np.isnan(z.T), z.T)
         Default = {'noise.sky': (1e0, 1e5),
@@ -375,7 +405,7 @@ class RTP():
 
         # set the background color, this needs to happen to avoid
         # the overlapping problem that occurs
-        # cmap.set_bad(color=background, alpha=1.)
+        cmap.set_bad(color=background, alpha=1.)
         # plot!
         im = ax.pcolormesh(time_axis, y_axis, z_data, lw=0.01,
                            cmap=cmap, norm=norm, **kwargs)
@@ -391,15 +421,16 @@ class RTP():
         ax.set_xlim([rounded_down_start_time, x[-1]])
         ax.xaxis.set_major_formatter(dates.DateFormatter(date_fmt))
         if ymax is None:
-            ymax = max(y)
+            ymax = np.max(y)
 
         if ymin is None:
-            ymin = min(y)
+            ymin = np.min(y)
 
         ax.set_ylim(ymin, ymax)
 
-        if slant:
-            ax.yaxis.set_ticks(np.arange(ymin, ymax+1, yspacing))
+        if coords is Coords.SLANT_RANGE or coords is Coords.GROUND_SCATTER_MAPPED_RANGE:
+            ax.yaxis.set_ticks(np.arange(np.ceil(ymin/100.0)*100,
+                                         ymax+1, yspacing))
         else:
             ax.yaxis.set_ticks(np.arange(ymin, ymax+1, (ymax)/5))
 
@@ -414,8 +445,9 @@ class RTP():
         else:
             tick_interval = 1
         ax.xaxis.set_minor_locator(dates.MinuteLocator(interval=tick_interval))
-        if slant:
-            ax.yaxis.set_minor_locator(ticker.MultipleLocator(100))
+
+        if coords is Coords.SLANT_RANGE or coords is Coords.GROUND_SCATTER_MAPPED_RANGE:
+            ax.yaxis.set_minor_locator(ticker.AutoMinorLocator(2))
         else:
             ax.yaxis.set_minor_locator(ticker.MultipleLocator(5))
         # so the plots gets to the ends
@@ -426,11 +458,14 @@ class RTP():
             with warnings.catch_warnings():
                 warnings.filterwarnings('error')
                 try:
-                    locator = ticker.MaxNLocator(symmetric=True, min_n_ticks=3,
-                                                 integer=True, nbins='auto')
-                    ticks = locator.tick_values(vmin=zmin, vmax=zmax)
-                    cb = ax.figure.colorbar(im, ax=ax, extend='both',
-                                            ticks=ticks)
+                    if isinstance(norm, colors.LogNorm):
+                        cb = ax.figure.colorbar(im, ax=ax, extend='both')
+                    else:
+                        locator = ticker.MaxNLocator(symmetric=True, min_n_ticks=3,
+                                                     integer=True, nbins='auto')
+                        ticks = locator.tick_values(vmin=zmin, vmax=zmax)
+                        cb = ax.figure.colorbar(im, ax=ax, extend='both',
+                                                ticks=ticks)
 
                 except (ZeroDivisionError, Warning):
                     raise rtp_exceptions.RTPZeroError(parameter, beam_num,
@@ -438,11 +473,7 @@ class RTP():
                                                       norm) from None
         if colorbar_label != '':
             cb.set_label(colorbar_label)
-        warnings.warn("Please make sure to cite pyDARN in publications that"
-                      " use plots created by pyDARN using DOI:"
-                      " https://zenodo.org/record/3978643. Citing information"
-                      " for SuperDARN data is found at"
-                      " https://pydarn.readthedocs.io/en/master/user/citing/")
+        citing_warning()
         return im, cb, cmap, x, y, z_data
 
     @classmethod
@@ -674,17 +705,15 @@ class RTP():
         ax.margins(x=0)
         ax.tick_params(axis='y', which='minor')
 
-        warnings.warn("Please make sure to cite pyDARN in publications that"
-                      " use plots created by pyDARN using DOI:"
-                      " https://zenodo.org/record/3978643. Citing information"
-                      " for SuperDARN data is found at"
-                      " https://pydarn.readthedocs.io/en/master/user/citing/")
+        citing_warning()
         return lines, x, y
 
     @classmethod
     def plot_summary(cls, dmap_data: List[dict], beam_num: int = 0,
                      groundscatter: bool = True, channel: int = 'all',
-                     slant: bool = True, figsize: tuple = (11, 8.5),
+                     coords: object = Coords.SLANT_RANGE,
+                     reflection_height: float = 250.0,
+                     figsize: tuple = (11, 8.5),
                      watermark: bool = True, boundary: dict = {},
                      background_color: str = 'w', cmaps: dict = {},
                      lines: dict = {}, plot_elv: bool = True, title=None):
@@ -696,7 +725,6 @@ class RTP():
         Future Work
         ------------
         day-night terminators
-        slant ranges
 
         Parameters
         ----------
@@ -717,10 +745,13 @@ class RTP():
             channel number that will be plotted
             in the summary plot.
             Default: 'all'
-        slant: bool
-            calculate slant range for range-gates if true.
-            False will use range-gate numbers
-            Default: True
+        coords: Coords
+            set the y-axis to a desired coordinate system
+            Default: Coords.SLANT_RANGE
+        reflection_height: float
+            set the ionosphere virtual reflection height
+            this only applies to Coords.GROUND_SCATTER_MAPPED_RANGE
+            Default: 250 (km)
         figsize : (int,int)
             tuple containing (height, width) figure size
             Default: 11 x 8.5
@@ -972,8 +1003,10 @@ class RTP():
             else:
                 # Current standard is to only have groundscatter
                 # on the velocity plot. This may change in the future.
-                if slant:
+                if coords is Coords.SLANT_RANGE:
                     ymax = 3517.5
+                elif coords is Coords.GROUND_SCATTER_MAPPED_RANGE:
+                    ymax = 3517.5/2
                 else:
                     ymax = 75
                 if groundscatter and axes_parameters[i] == 'v':
@@ -993,7 +1026,8 @@ class RTP():
                                             ax=axes[i],
                                             groundscatter=grndflg,
                                             channel=channel,
-                                            slant=slant,
+                                            coords=coords,
+                                            reflection_height = reflection_height,
                                             cmap=cmap[axes_parameters[i]],
                                             zmin=boundary_ranges[axes_parameters[i]][0],
                                             zmax=boundary_ranges[axes_parameters[i]][1],
@@ -1006,16 +1040,19 @@ class RTP():
                 if axes_parameters[i] == 'v':
                     locator = ticker.LinearLocator(numticks=5)
                     ticks =\
-                        locator.tick_values(vmin=boundary_ranges[axes_parameters[i]][0],
-                                            vmax=boundary_ranges[axes_parameters[i]][1])
+                        locator.\
+                        tick_values(vmin=boundary_ranges[axes_parameters[i]][0],
+                                    vmax=boundary_ranges[axes_parameters[i]][1])
                     if ticks[0] < boundary_ranges[axes_parameters[i]][0]:
                         ticks[0] = boundary_ranges[axes_parameters[i]][0]
 
                     if ticks[-1] > boundary_ranges[axes_parameters[i]][1]:
                         ticks[-1] = boundary_ranges[axes_parameters[i]][1]
                     cbar.set_ticks(ticks)
-                if slant:
+                if coords is Coords.SLANT_RANGE:
                     axes[i].set_ylabel('Slant Range (km)')
+                elif coords is Coords.GROUND_SCATTER_MAPPED_RANGE:
+                    axes[i].set_ylabel('Ground Scatter\nMapped Range\n(km)')
                 else:
                     axes[i].set_ylabel('Range Gates')
             if i < num_plots-1:
@@ -1035,12 +1072,7 @@ class RTP():
                      color='gray', ha='right', va='top',
                      rotation=-38, alpha=0.3)
 
-        warnings.warn("Please make sure to cite pyDARN in publications that"
-                      " use plots created by pyDARN using DOI:"
-                      " https://zenodo.org/record/3978643. Citing information"
-                      " for SuperDARN data is found at"
-                      " https://pydarn.readthedocs.io/en/master/user/citing/")
-
+        citing_warning()
         return fig, axes
 
     @classmethod
